@@ -367,10 +367,7 @@ sub hex2char {
     return $value unless $value =~ /^0x/;
 
     $value =~ s/^0x//; # drop hex prefix
-    $value =~ s/00$//; # drop trailing null-character
-    $value =~ s/(\w{2})/chr(hex($1))/eg;
-
-    return $value;
+    return pack('H*', $value);
 }
 
 sub hex2dec {
