@@ -469,20 +469,29 @@ sub _getSerial {
 sub _getFirmware {
     my ($snmp, $type) = @_;
 
-    my @oids = (
-        '.1.3.6.1.2.1.47.1.1.1.1.9.1',
-        '.1.3.6.1.2.1.47.1.1.1.1.9.1000',
-        '.1.3.6.1.2.1.47.1.1.1.1.9.1001',
-        '.1.3.6.1.2.1.47.1.1.1.1.10.1',
-        '.1.3.6.1.4.1.9.9.25.1.1.1.2.5'
-    );
-
-    foreach my $oid (@oids) {
-        my $value = $snmp->get($oid);
-        next unless $value;
-        return $value;
+    my $entPhysicalSoftwareRev = $snmp->walk('.1.3.6.1.2.1.47.1.1.1.1.10');
+    if ($entPhysicalSoftwareRev) {
+        my $firmware =
+            first { $_ }
+            map   { $entPhysicalSoftwareRev->{$_} }
+            sort  { $a <=> $b }
+            keys %$entPhysicalSoftwareRev;
+        return $firmware if $firmware;
     }
 
+    my $entPhysicalFirmwareRev = $snmp->walk('.1.3.6.1.2.1.47.1.1.1.1.9');
+    if ($entPhysicalFirmwareRev) {
+        my $firmware =
+            first { $_ }
+            map   { $entPhysicalFirmwareRev->{$_} }
+            sort  { $a <=> $b }
+            keys %$entPhysicalFirmwareRev;
+        return $firmware if $firmware;
+    }
+
+    my $ios_version = $snmp->walk('.1.3.6.1.4.1.9.9.25.1.1.1.2.5');
+    return $ios_version if $ios_version;
+
     return;
 }
 
